==> apache-beam-2.43.0-source-release.zip: beam-2.43.0/playground/frontend/lib/components/banner/banner_button.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:aligned_dialog/aligned_dialog.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:playground/components/banner/banner_description.dart';
import 'package:playground/constants/assets.dart';

class BannerButton extends StatelessWidget {
  const BannerButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      cursor: SystemMouseCursors.click,
      onHover: (_) {
        showAlignedDialog(
          context: context,
          builder: (dialogContext) => const BannerDescription(),
          followerAnchor: Alignment.topRight,
          targetAnchor: Alignment.topRight,
          barrierColor: Colors.transparent,
        );
      },
      child: SvgPicture.asset(kBeamIconAsset),
    );
  }
}

==> apache-beam-2.71.0-source-release.zip: beam-2.71.0/playground/frontend/lib/components/banner/banner_button.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:aligned_dialog/aligned_dialog.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../src/assets/assets.gen.dart';
import 'banner_description.dart';

class BannerButton extends StatelessWidget {
  const BannerButton({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      cursor: SystemMouseCursors.click,
      onHover: (_) {
        showAlignedDialog(
          context: context,
          builder: (dialogContext) => const BannerDescription(),
          followerAnchor: Alignment.topRight,
          targetAnchor: Alignment.topRight,
          barrierColor: Colors.transparent,
        );
      },
      child: SvgPicture.asset(Assets.beam.path),
    );
  }
}
